==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/SemanticTitleOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for linting that PR titles follow Conventional Commits.
 * <p>
 * @see https://www.conventionalcommits.org/
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.770Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.SemanticTitleOptions")
@software.amazon.jsii.Jsii.Proxy(SemanticTitleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface SemanticTitleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Configure that a scope must always be provided.
     * <p>
     * e.g. feat(ui), fix(core)
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getRequireScope() {
        return null;
    }

    /**
     * (experimental) Configure a list of commit types that are allowed.
     * <p>
     * Default: ["feat", "fix", "chore"]
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getTypes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SemanticTitleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SemanticTitleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<SemanticTitleOptions> {
        java.lang.Boolean requireScope;
        java.util.List<java.lang.String> types;

        /**
         * Sets the value of {@link SemanticTitleOptions#getRequireScope}
         * @param requireScope Configure that a scope must always be provided.
         *                     e.g. feat(ui), fix(core)
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder requireScope(java.lang.Boolean requireScope) {
            this.requireScope = requireScope;
            return this;
        }

        /**
         * Sets the value of {@link SemanticTitleOptions#getTypes}
         * @param types Configure a list of commit types that are allowed.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder types(java.util.List<java.lang.String> types) {
            this.types = types;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SemanticTitleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public SemanticTitleOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SemanticTitleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SemanticTitleOptions {
        private final java.lang.Boolean requireScope;
        private final java.util.List<java.lang.String> types;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.requireScope = software.amazon.jsii.Kernel.get(this, "requireScope", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.types = software.amazon.jsii.Kernel.get(this, "types", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.requireScope = builder.requireScope;
            this.types = builder.types;
        }

        @Override
        public final java.lang.Boolean getRequireScope() {
            return this.requireScope;
        }

        @Override
        public final java.util.List<java.lang.String> getTypes() {
            return this.types;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getRequireScope() != null) {
                data.set("requireScope", om.valueToTree(this.getRequireScope()));
            }
            if (this.getTypes() != null) {
                data.set("types", om.valueToTree(this.getTypes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.SemanticTitleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SemanticTitleOptions.Jsii$Proxy that = (SemanticTitleOptions.Jsii$Proxy) o;

            if (this.requireScope != null ? !this.requireScope.equals(that.requireScope) : that.requireScope != null) return false;
            return this.types != null ? this.types.equals(that.types) : that.types == null;
        }

        @Override
        public final int hashCode() {
            int result = this.requireScope != null ? this.requireScope.hashCode() : 0;
            result = 31 * result + (this.types != null ? this.types.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/SemanticTitleOptions.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Options for linting that PR titles follow Conventional Commits.
 * <p>
 * @see <a href="https://www.conventionalcommits.org/">https://www.conventionalcommits.org/</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.436Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.SemanticTitleOptions")
@software.amazon.jsii.Jsii.Proxy(SemanticTitleOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface SemanticTitleOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Configure that a scope must always be provided.
     * <p>
     * e.g. feat(ui), fix(core)
     * <p>
     * Default: false
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getRequireScope() {
        return null;
    }

    /**
     * (experimental) Configure a list of commit types that are allowed.
     * <p>
     * Default: ["feat", "fix", "chore"]
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.lang.String> getTypes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link SemanticTitleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link SemanticTitleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<SemanticTitleOptions> {
        java.lang.Boolean requireScope;
        java.util.List<java.lang.String> types;

        /**
         * Sets the value of {@link SemanticTitleOptions#getRequireScope}
         * @param requireScope Configure that a scope must always be provided.
         *                     e.g. feat(ui), fix(core)
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder requireScope(java.lang.Boolean requireScope) {
            this.requireScope = requireScope;
            return this;
        }

        /**
         * Sets the value of {@link SemanticTitleOptions#getTypes}
         * @param types Configure a list of commit types that are allowed.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder types(java.util.List<java.lang.String> types) {
            this.types = types;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link SemanticTitleOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public SemanticTitleOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link SemanticTitleOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements SemanticTitleOptions {
        private final java.lang.Boolean requireScope;
        private final java.util.List<java.lang.String> types;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.requireScope = software.amazon.jsii.Kernel.get(this, "requireScope", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.types = software.amazon.jsii.Kernel.get(this, "types", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.requireScope = builder.requireScope;
            this.types = builder.types;
        }

        @Override
        public final java.lang.Boolean getRequireScope() {
            return this.requireScope;
        }

        @Override
        public final java.util.List<java.lang.String> getTypes() {
            return this.types;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getRequireScope() != null) {
                data.set("requireScope", om.valueToTree(this.getRequireScope()));
            }
            if (this.getTypes() != null) {
                data.set("types", om.valueToTree(this.getTypes()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.SemanticTitleOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            SemanticTitleOptions.Jsii$Proxy that = (SemanticTitleOptions.Jsii$Proxy) o;

            if (this.requireScope != null ? !this.requireScope.equals(that.requireScope) : that.requireScope != null) return false;
            return this.types != null ? this.types.equals(that.types) : that.types == null;
        }

        @Override
        public final int hashCode() {
            int result = this.requireScope != null ? this.requireScope.hashCode() : 0;
            result = 31 * result + (this.types != null ? this.types.hashCode() : 0);
            return result;
        }
    }
}
